##############
PredictJob API
##############

.. _wait_for_async_predictions-api-label:
.. autofunction:: datarobot.models.predict_job.wait_for_async_predictions

.. autoclass:: datarobot.models.PredictJob
   :members:
